#! /bin/bash

PACKAGE_NAME="printer-driver-bisheng-canon-lbp3410-lips"
PACKAGE_VERSION="2.0.1"
PRINTER_NAME=( "Canon LBP3410 LIPS" "Canon LBP3700 LIPS" "Canon LBP3800 LIPS" "Canon LBP3900-3950 LIPS" "Canon LBP3910-3930 LIPS" "Canon LBP3920-3970 LIPS" "Canon LBP3980 LIPS" "Canon LBP3980M LIPS" "Canon LBP4500 LIPS" "Canon LBP5400 LIPS" "Canon LBP5500 LIPS" "Canon LBP5700 LIPS" "Canon LBP5800 LIPS" "Canon LBP5900 LIPS" "Canon LBP5910 LIPS" "Canon LBP5910M LIPS" "Canon LBP7700C LIPS" "Canon LBP9600C LIPS" "Canon LASER SHOT LBP-1310" "Canon LASER SHOT LBP-1420" "Canon LASER SHOT LBP-1610" "Canon LASER SHOT LBP-1620" "Canon LASER SHOT LBP-1810" "Canon LASER SHOT LBP-1820" "Canon LASER SHOT LBP-1910" "Canon LASER SHOT LBP-2050" "Canon LASER SHOT LBP-2510" "Canon LASER SHOT LBP-2710" "Canon LASER SHOT LBP-2810" "Canon iR400-GP405 LIPS-D2" "Canon iR105 LIPS" "Canon iR105-E LIPS" "Canon iR105i LIPS" "Canon iR1600-2000 LIPS" "Canon iR2200-3300 LIPS" "Canon iR2250-2850-3350 LIPS" "Canon iR2270-iR2870 LIPS" "Canon iR3025 LIPS" "Canon iR3035-iR3045 LIPS" "Canon iR3225 LIPS" "Canon iR3235-iR3245 LIPS" "Canon iR3570-iR4570 LIPS" "Canon iR5000-6000" "Canon iR5055-iR5065 LIPS" "Canon iR5075 LIPS" "Canon iR5150-iR6050 LIPS" "Canon iR5160-iR6060 LIPS" "Canon iR5570-iR6570 LIPS" "Canon iR7086-7105 LIPS" "Canon iR7200 LIPS" "Canon iR7200-E LIPS" "Canon iR7270N LIPS" "Canon iR8500 LIPS" "Canon iR8500-E LIPS" "Canon iR8570N LIPS" "Canon iR C2570 LIPS" "Canon iR C2620 LIPS" "Canon iR C2880-C3380 LIPS" "Canon iR C3080-C3580 LIPS" "Canon iR C3100 LIPS" "Canon iR C3170 LIPS" "Canon iR C3200 LIPS" "Canon iR C3220 LIPS" "Canon iR C3880-C4580 LIPS" "Canon iR C4080 LIPS" "Canon iR C5180 LIPS" "Canon iR C5185 LIPS" "Canon iR C5800 LIPS" "Canon iR C5870 LIPS" "Canon iR C5880-C6880 LIPS" "Canon iR C6800 LIPS" "Canon iR C6870 LIPS" "Canon BIJ1350 LIPS" "Canon BIJ1350D LIPS" "Canon BIJ2350 LIPS" "Canon iPR C1 LIPS" "Canon iPR C1PLUS LIPS" "Canon iPR C6000 LIPS" "Canon iPR C7000VP LIPS" )

CONTAINER_PATH="$HOME/.deepinwine/$PACKAGE_NAME"
OPT_PATH="/opt/deepinwine/printer_drv/$PACKAGE_NAME"
WINEBIN="bisheng"
REGDIR="reg"
FILEDIR="files"

PRINTER_C=$1
found=0
for name in "${PRINTER_NAME[@]}"; do
    if [ "$PRINTER_C" = "$name" ]; then
        found=1
        break
    fi
done

if [ $found -eq 0 ]; then
    echo "printer $PRINTER_C not found"
    exit 0
fi

if [ -z "$PACKAGE_NAME" -o ! -d "$OPT_PATH" ]; then
    exit 1
fi

if [ -d "$CONTAINER_PATH" ]; then
    # compare version
    if [ ! -f "$CONTAINER_PATH/VERSION" ] || [ "$(cat "$CONTAINER_PATH/VERSION")" != "$PACKAGE_VERSION" ]; then
        rm -rf "$CONTAINER_PATH"
    fi
fi

WININI="$CONTAINER_PATH/drive_c/windows/win.ini"
if [ -f  $WININI ]; then
    grep -q "^$PRINTER_C=winerp.drv,USB" "$WININI" && exit 0
fi

if [ -d "$OPT_PATH/$REGDIR" ]; then
    find "$OPT_PATH/$REGDIR" -type f -regex ".*\.reg" | while read file; do
        WINEPREFIX=$CONTAINER_PATH $WINEBIN regedit "$file"
    done
fi

if [ -d "$OPT_PATH/$FILEDIR" ]; then
    find "$OPT_PATH/$FILEDIR" -not -type d | while read file; do
        path="$CONTAINER_PATH/drive_c/${file#*$FILEDIR/}"
        dir="${path%/*}"
        mkdir -p "$dir"
        cp -d "$file" "$path"
    done
fi

if [ -f "$WININI" ]; then
    grep -q "^\[devices\]" "$WININI" || sed -i -e "$ a [devices]" "$WININI"
    grep -q "^\[PrinterPorts\]" "$WININI" || sed -i -e "$ a [PrinterPorts]" "$WININI"
    sed -i -e "/^\[devices\]/a $PRINTER_C=winerp.drv,USB" "$WININI"
    sed -i -e "/^\[PrinterPorts\]/a $PRINTER_C=winerp.drv,USB,15,45" "$WININI"
fi

WINESERVER_RUNNING=1
WINESERVER_FINDNUM=0
while [ $WINESERVER_RUNNING -eq 1 ]
do
        WINESERVER_PATH=`ps -aux|grep wineserver|grep -v grep`
        if [ "$WINESERVER_PATH" = "" ] || [ $WINESERVER_FINDNUM -eq 3 ]; then
                WINESERVER_RUNNING=0
        else
                let WINESERVER_FINDNUM+=1
                sleep 1
        fi
done

echo "$PACKAGE_VERSION" > "$CONTAINER_PATH/VERSION"
echo "$PRINTER_NAME" > "$CONTAINER_PATH/name.log"
